pro pt_event, event

end



pro pt

  ; INPUT
  OBSfile = 'OBS-T-00001.xml'   ; The OBS filename
  OBSdir = 'XMLTest/'       ; OBS-file directory
  copyxml=1       ;set to 1 if you want to copy the xml-files to the destination folder
  destination='XMLcopy' ;destination folder for xml-copies
  
  if destination ne '' then spawn, "mkdir "+destination
  
  
  ;get data from XML-files and save the xml-files to the above created folder
  readtables, OBSfile, OBSdir, OBSList, FRMList, FDBList, CRSList, error, copyxml, destination
  
  ; check for errors while reading the XML-files
  if error then begin
    print,'There is something wrong with the given OBS file, exiting program'
    return
  endif
  
  
  
  
  ; MainWindow ; Base-Widget
  MainWindow = WIDGET_BASE(/COLUMN)
  ObsBase = WIDGET_BASE(MainWindow, /COLUMN, Frame=3)
  Title_Label = WIDGET_LABEL(ObsBase, Value='Observing List Table', Frame=2)
  
  ; Header-information
  headerBase1 = WIDGET_BASE(ObsBase, /ROW)
  ID_field = CW_FIELD(headerBase1, Title='ID', Value=OBSList.ID, /NoEdit)
  Size_field = CW_FIELD(headerBase1, Title='Size', Value=OBSList.TableSize, /NoEdit)
  Entries_field = CW_FIELD(headerBase1, Title='Entries', Value=OBSList.NumEntries, /NoEdit)
  headerBase2 = WIDGET_BASE(ObsBase, /ROW)
  Tref_field = CW_FIELD(headerBase2, Title='Tref', Value=OBSList.Tref_Obs, /NoEdit)
  Rep_field = CW_FIELD(headerBase2, Title='Repeat', Value=OBSList.Repeat_Obs, /NoEdit)
  Cad_field = CW_FIELD(headerBase2, Title='Cadence', Value=OBSList.Cadence_Obs, /NoEdit)
  headerBase3 = WIDGET_BASE(ObsBase, /ROW)
  Desc_field = CW_FIELD(headerBase3, Title='Description', Value=OBSList.Description, /NoEdit)
  Time_field = CW_FIELD(headerBase3, Title='Time', Value=OBSList.Time, /NoEdit)
  DataS_field = CW_FIELD(headerBase3, Title='Datasize', Value=OBSList.DataSize, /NoEdit)
  
  ; Data
  ;first we create a new structure for the table
  void = {ObsTable, Tref:0L, FID:'', Rep:0L, Flush:0L, Tag:'', Cad:0L, $
    PZTX:0.0d, PZTY:0.0d, dPZTX:0.0d, dPZTY:0.0d}
  showData = MAKE_ARRAY(OBSList.NumEntries, Value={ObsTable})
  
  for i=0,OBSList.NumEntries-1 do begin
    showData[i].Tref = (*(OBSList).Tref_FRM)[i]
    showData[i].FID = (*(OBSList).FRM_ID)[i]
    showData[i].Rep = (*(OBSList).Repeat_FRM)[i]
    showData[i].Flush = (*(OBSList).Flush)[i]
    showData[i].Tag = (*(OBSList).Tag)[i]
    showData[i].Cad = (*(OBSList).Cadence_FRM)[i]
    xy = pzt2xy((*(OBSList).PZT_A_Abs)[i], (*(OBSList).PZT_B_Abs)[i], (*(OBSList).PZT_C_Abs)[i])
    showData[i].PZTX = xy[0]
    showData[i].PZTY = xy[1]
    xy = pzt2xy((*(OBSList).PZT_A_Step)[i], (*(OBSList).PZT_B_Step)[i], (*(OBSList).PZT_C_Step)[i])
    showData[i].dPZTX = xy[0]
    showData[i].dPZTY = xy[1]
  endfor
  ColumnLabels = ['rel. Time', 'Frame ID', 'Repeats', 'FLush', 'Tag', 'Cadence', $
    'OFF X', 'OFF Y', 'Step X', 'Step Y']
  Data_table = WIDGET_TABLE(ObsBase, Column_Labels=ColumnLabels, /No_Row_Headers, $
    Value=showData)
    
  WIDGET_CONTROL, MainWindow, /realize
  
  
  
  
  
  
  for j=0,N_ELEMENTS(FRMList)-1 do begin
    FRMBase = WIDGET_BASE(/COLUMN, group_leader=MainWindow, XOffset=200, YOffset=100*j)
    Title_Label = WIDGET_LABEL(FRMBase, Value='Frame List Table', Frame=2)
    
    ; Header-information
    headerBase1 = WIDGET_BASE(FRMBase, /ROW)
    ID_field = CW_FIELD(headerBase1, Title='ID', Value=FRMList[j].ID, /NoEdit)
    Size_field = CW_FIELD(headerBase1, Title='Size', Value=FRMList[j].Tablesize, /NoEdit)
    Entries_field = CW_FIELD(headerBase1, Title='Entries', Value=FRMList[j].NumEntries, /NoEdit)
    headerBase3 = WIDGET_BASE(FRMBase, /ROW)
    Desc_field = CW_FIELD(headerBase3, Title='Description', Value=FRMList[j].Description, /NoEdit)
    Time_field = CW_FIELD(headerBase3, Title='Time', Value=FRMList[j].Time, /NoEdit)
    DataS_field = CW_FIELD(headerBase3, Title='Datasize', Value=FRMList[j].DataSize, /NoEdit)
    
    ; Data
    ;first we create a new structure for the table
    void = {frmtable, Tref:0L, SJI:'', NUV:'', FUV:'', $
      SJI_AEC:'', NUV_AEC:'', FUV_AEC:'', $
      Flags:0L, FW:0L, Focus:0L, $
      PZTX:0.0d, PZTY:0.0d}
    showData = MAKE_ARRAY(FRMList[j].NumEntries, Value={frmtable})
    
    for i=0,FRMList[j].NumEntries-1 do begin
      showData[i].Tref = (*(FRMList[j]).Tref)[i]
      showData[i].SJI = (*(FRMList[j]).SJI_FDB_ID)[i]
      showData[i].NUV = (*(FRMList[j]).NUV_SG_FDB_ID)[i]
      showData[i].FUV = (*(FRMList[j]).FUV1_SG_FDB_ID)[i]
      showData[i].SJI_AEC = (*(FRMList[j]).SJI_AEC)[i]
      showData[i].NUV_AEC = (*(FRMList[j]).NUV_AEC)[i]
      showData[i].FUV_AEC = (*(FRMList[j]).FUV_AEC)[i]
      showData[i].Flags = (*(FRMList[j]).Flags)[i]
      showData[i].FW = (*(FRMList[j]).FW)[i]
      showData[i].Focus = (*(FRMList[j]).FOCUS)[i]
      xy = pzt2xy((*(FRMList[j]).PZT_A_Rel)[i], (*(FRMList[j]).PZT_B_Rel)[i], (*(FRMList[j]).PZT_C_Rel)[i])
      showData[i].PZTX = xy[0]
      showData[i].PZTY = xy[1]
    endfor
    ColumnLabels = ['rel. Time', 'SJI ID', 'NUV ID', 'FUV ID', $
      'SJI_AEC', 'NUV_AEC', 'FUV_AEC', $
      'Flags', 'FW', 'Focus', $
      'PZT X', 'PZT Y']
    Data_table = WIDGET_TABLE(FRMBase, Column_Labels=ColumnLabels, /No_Row_Headers, $
      Value=showData)
      
    widget_control, FRMBase, /realize
    xmanager, 'pt', FRMBase, /just_reg
    
  endfor ;FRMList
  
  
  
  
  
  for j=0,N_ELEMENTS(FDBList)-1 do begin
    FDBBase = WIDGET_BASE(/COLUMN, group_leader=MainWindow, XOffset=400, YOffset=100*j)
    Title_Label = WIDGET_LABEL(FDBBase, Value='Frame Definition Block Table', Frame=2)
    
    ; Header-information
    headerBase1 = WIDGET_BASE(FDBBase, /ROW)
    ID_field = CW_FIELD(headerBase1, Title='ID', Value=FDBList[j].ID, /NoEdit)
    Size_field = CW_FIELD(headerBase1, Title='Size', Value=FDBList[j].Tablesize, /NoEdit)
    headerBase3 = WIDGET_BASE(FDBBase, /ROW)
    Desc_field = CW_FIELD(headerBase3, Title='Description', Value=FDBList[j].Description, /NoEdit)
    Time_field = CW_FIELD(headerBase3, Title='Time', Value=FDBList[j].Time, /NoEdit)
    DataS_field = CW_FIELD(headerBase3, Title='Datasize', Value=FDBList[j].DataSize, /NoEdit)
    
    ; Data
    ;first we create a new structure for the table
    void = {fdbtable, CRSID:'', Exp_Duration:0L, Exp_Type:0L, CompN:0L, CompK:0L, $
      LookupTableID:'', Exp_Max:0L}
    showData = MAKE_ARRAY(1, Value={fdbtable})
    
    for i=0,0 do begin
      showData[i].CRSID = FDBList[j].CRSID[i]
      showData[i].Exp_Duration = FDBList[j].Exp_Duration[i]
      showData[i].Exp_Type = FDBList[j].Exp_Type[i]
      showData[i].CompN = FDBList[j].CompN[i]
      showData[i].CompK = FDBList[j].CompK[i]
      showData[i].LookupTableID = FDBList[j].LookupTableID[i]
      showData[i].Exp_Max = FDBList[j].Exp_Max[i]
    endfor
    ColumnLabels = ['CRS ID', 'Exp_Duration', 'Exp_Type', 'CompN', 'CompK', 'LookupTableID', 'Exp_Max']
    Data_table = WIDGET_TABLE(FDBBase, Column_Labels=ColumnLabels, /No_Row_Headers, $
      Value=showData)
      
    widget_control, FDBBase, /realize
    xmanager, 'pt', FDBBase, /just_reg
    
  endfor ;FDBList
  
  
  
  
  
  for j=0,N_ELEMENTS(CRSList)-1 do begin
    CRSBase = WIDGET_BASE(/COLUMN, group_leader=MainWindow, XOffset=600, YOffset=100*j)
    Title_Label = WIDGET_LABEL(CRSBase, Value='CCD Readout Spec Table', Frame=2)
    
    ; Header-information
    headerBase1 = WIDGET_BASE(CRSBase, /ROW)
    ID_field = CW_FIELD(headerBase1, Title='ID', Value=CRSList[j].ID, /NoEdit)
    Size_field = CW_FIELD(headerBase1, Title='Size', Value=CRSList[j].Tablesize, /NoEdit)
    Entries_field = CW_FIELD(headerBase1, Title='Subregions', Value=CRSList[j].SubRegions, /NoEdit)
    headerBase2 = WIDGET_BASE(CRSBase, /ROW)
    Spectral_field = CW_FIELD(headerBase2, Title='Spectral', Value=CRSList[j].Spectral, /NoEdit)
    Spatial_field = CW_FIELD(headerBase2, Title='Spatial', Value=CRSList[j].Spatial, /NoEdit)
    headerBase3 = WIDGET_BASE(CRSBase, /ROW)
    Desc_field = CW_FIELD(headerBase3, Title='Description', Value=CRSList[j].Description, /NoEdit)
    Time_field = CW_FIELD(headerBase3, Title='Time', Value=CRSList[j].Time, /NoEdit)
    DataS_field = CW_FIELD(headerBase3, Title='Datasize', Value=CRSList[j].DataSize, /NoEdit)
    
    ; Data
    ;first we create a new structure for the table
    void = {crstable, SubRegionID:0L, StartRow:0L, NumRows:0L, StartCol:0L, NumCols:0L}
    showData = MAKE_ARRAY(CRSList[j].SubRegions, Value={crstable})
    for i=0,CRSList[j].SubRegions-1 do begin
      showData[i].SubRegionID = (*(CRSList[j]).SubRegionID)[i]
      showData[i].StartRow = (*(CRSList[j]).StartRow)[i]+1
      showData[i].NumRows = (*(CRSList[j]).NumRows)[i]+(*(CRSList[j]).StartRow)[i]-1
      showData[i].StartCol = (*(CRSList[j]).StartCol)[i]+1
      showData[i].NumCols = (*(CRSList[j]).NumCols)[i]+(*(CRSList[j]).StartCol)[i]-1
    endfor
    ColumnLabels = ['SubRegion ID', 'StartRow', 'EndRow', 'StartCol', 'EndCol']
    Data_table = WIDGET_TABLE(CRSBase, Column_Labels=ColumnLabels, /No_Row_Headers, $
      Value=showData)
      
    widget_control, CRSBase, /realize
    xmanager, 'pt', CRSBase, /just_reg
    
  endfor ;CRSList
  
  
  
  xmanager, 'pt', MainWindow
  
end
